tiled.client.context.Context
============================

.. currentmodule:: tiled.client.context

.. autoclass:: Context

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Context.__init__
      ~Context.authenticate
      ~Context.create_api_key
      ~Context.disable_cache
      ~Context.get_content
      ~Context.get_json
      ~Context.logout
      ~Context.post_json
      ~Context.reauthenticate
      ~Context.revalidation
      ~Context.revoke_api_key
      ~Context.revoke_session
      ~Context.which_api_key
      ~Context.whoami
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Context.api_key
      ~Context.app
      ~Context.base_url
      ~Context.cache
      ~Context.event_hooks
      ~Context.offline
      ~Context.path_parts
      ~Context.revalidate
      ~Context.tokens
   
   